errorPolicy property
Defines the error handling policy for load operations. By default, all errors are shown in the UI.
Implementation
Set<LoadErrorPolicy> errorPolicy;
Defines the error handling policy for load operations. By default, all errors are shown in the UI.
Set<LoadErrorPolicy> errorPolicy;