autoLoadPrepend property
Automatically load more data at the beginning of the list when reaching the boundary.
Implementation
final bool autoLoadPrepend;
Automatically load more data at the beginning of the list when reaching the boundary.
final bool autoLoadPrepend;