insertItem method

void insertItem(
  1. int index,
  2. Value item
)
inherited

Inserts an item at the specified index and notifies listeners.

If the index is out of range, an error will be set in the state manager.

Implementation

void insertItem(int index, Value item) {
  notifier.insertItem(index, item);
}