stickyHeader property
If true, group headers will remain visible at the top of the screen
as the user scrolls down through the items in that group.
Implementation
final bool stickyHeader;
If true, group headers will remain visible at the top of the screen
as the user scrolls down through the items in that group.
final bool stickyHeader;