appendLoadingWidget property
The widget that is shown when the data is loading at the end of the list.
Implementation
final Widget? appendLoadingWidget;
The widget that is shown when the data is loading at the end of the list.
final Widget? appendLoadingWidget;