fillRemainEmptyWidget property
If true, the empty widget will fill the remaining space of the viewport.
Implementation
final bool fillRemainEmptyWidget;
If true, the empty widget will fill the remaining space of the viewport.
final bool fillRemainEmptyWidget;