fillRemainErrorWidget property
If true, the error widget will fill the remaining space of the viewport.
Implementation
final bool fillRemainErrorWidget;
If true, the error widget will fill the remaining space of the viewport.
final bool fillRemainErrorWidget;