initialLoadingWidget property
The widget that is shown when the data is loading for the first time.
Implementation
final Widget? initialLoadingWidget;
The widget that is shown when the data is loading for the first time.
final Widget? initialLoadingWidget;