prependLoadingWidget property
The widget that is shown when the data is loading at the beginning of the list.
Implementation
final Widget? prependLoadingWidget;
The widget that is shown when the data is loading at the beginning of the list.
final Widget? prependLoadingWidget;